@@ -1,33 +1,33 @@
 # Version of the pyhts package
-__version__ = "0.1.5"
+__version__ = "0.2.0"
 
 __all__ = [
     "Hierarchy",
-    "Hts",
+    "TemporalHierarchy",
+    "TemporalHFModel",
     "BaseForecaster",
     "AutoArimaForecaster",
     "HFModel",
-    "wls",
+    "mint",
     "mape",
     "mase",
     "smape",
     "rmsse",
     "rmse",
     "mae",
-    "mse"
+    "mse",
+    "load_tourism"
 ]
 
-from pyhts._hierarchy import Hierarchy
+from pyhts._hierarchy import *
 from pyhts._forecaster import (
     BaseForecaster,
     AutoArimaForecaster
 )
 
-from pyhts._HFModel import HFModel
+from pyhts._HFModel import HFModel, TemporalHFModel
 
-from pyhts._reconciliation import wls
-
-from pyhts._hts import Hts
+from pyhts._reconciliation import mint
 
 from pyhts._accuracy import (
     mae,
@@ -37,4 +37,6 @@ from pyhts._accuracy import (
     rmsse,
     smape,
     mse
-)
\ No newline at end of file
+)
+
+from pyhts._dataset import load_tourism
\ No newline at end of file
